---
title: "Documentation"
linkTitle: "Documentation"
weight: 20
menu:
  main:
    weight: 20
---

CyanoByte is a YAML based specification for formally defining embedded communications.
It allows for both documentation and code to be generated from the CyanoByte files.
The specification was greatly inspired by the successes of OpenAPI. 